@@ -1,10 +1,12 @@
 from .utils_class import UtilsClass
 from .utils_config import UtilsConfig
 from .utils_env import UtilsEnv
+from .utils_file import UtilsFile
 from .utils_id import UtilsId
 from .utils_image import UtilsImage
 from .utils_method import UtilsMethod
 from .utils_opencv import UtilsOpencv
+from .utils_pdf import UtilsPdf
 from .utils_ping import UtilsPing
 from .utils_random import UtilsRandom
 from .utils_string import UtilsString
@@ -14,10 +16,12 @@ __all__ = [
     UtilsClass,
     UtilsConfig,
     UtilsEnv,
+    UtilsFile,
     UtilsId,
     UtilsImage,
     UtilsMethod,
     UtilsOpencv,
+    UtilsPdf,
     UtilsPing,
     UtilsRandom,
     UtilsString,
